@@ -64,12 +64,12 @@
 #define R__HAS_DEFAULT_ZLIB  /**/
 #undef R__HAS_DEFAULT_LZMA  /**/
 #undef R__HAS_DEFAULT_ZSTD  /**/
-#define R__HAS_CLOUDFLARE_ZLIB /**/
+#undef R__HAS_CLOUDFLARE_ZLIB /**/
 
-#undef R__HAS_TMVACPU /**/
+#define R__HAS_TMVACPU /**/
 #undef R__HAS_TMVAGPU /**/
 #undef R__HAS_CUDNN /**/
-#define R__HAS_PYMVA /**/
+#undef R__HAS_PYMVA /**/
 #undef R__HAS_RMVA /**/
 
 #undef R__HAS_URING /**/
